import * as i4 from '@angular/common';
import { DOCUMENT, CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Injectable, Inject, EventEmitter, forwardRef, Component, ViewEncapsulation, Input, HostBinding, Output, ViewChild, HostListener, SecurityContext, Attribute, NgModule } from '@angular/core';
import * as i1 from '@angular/common/http';
import { HttpResponse } from '@angular/common/http';
import * as i5 from '@angular/forms';
import { NG_VALUE_ACCESSOR, FormsModule, ReactiveFormsModule } from '@angular/forms';
import * as i2 from '@tinkoff/ng-dompurify';
import * as i1$2 from '@fortawesome/angular-fontawesome';
import { FontAwesomeModule } from '@fortawesome/angular-fontawesome';
import * as i1$1 from '@ng-bootstrap/ng-bootstrap';
import { NgbDropdownModule } from '@ng-bootstrap/ng-bootstrap';
import * as i6 from 'ngx-color-picker';
import { ColorPickerModule } from 'ngx-color-picker';
import { faItalic, faBold, faSuperscript, faSubscript, faUnderline, faUndo, faAlignRight, faAlignCenter, faAlignLeft, faAlignJustify, faRedo, faStrikethrough, faIndent, faOutdent, faListUl, faListOl, faFont, faLink, faUnlink, faImage, faVideo, faMinus, faRemoveFormat, faCode, faHighlighter } from '@fortawesome/free-solid-svg-icons';

class AngularEditorService {
    constructor(http, doc, rendererFactory) {
        this.http = http;
        this.doc = doc;
        /**
         * save selection when the editor is focussed out
         */
        this.saveSelection = () => {
            if (this.doc.getSelection) {
                const sel = this.doc.getSelection();
                if (sel.getRangeAt && sel.rangeCount) {
                    this.savedSelection = sel.getRangeAt(0);
                    this.selectedText = sel.toString();
                }
            }
            else if (this.doc.getSelection && this.doc.createRange) {
                this.savedSelection = document.createRange();
            }
            else {
                this.savedSelection = null;
            }
        };
        this.renderer = rendererFactory.createRenderer(null, null);
    }
    setTextArea(textArea) {
        this.textArea = textArea;
    }
    /**
     * Executed command from editor header buttons exclude toggleEditorMode
     * @param command string from triggerCommand
     */
    executeCommand(command) {
        const commands = ['h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'p', 'pre'];
        if (commands.includes(command)) {
            this.doc.execCommand('formatBlock', false, command);
            return;
        }
        this.doc.execCommand(command, false, null);
    }
    insertVariable(variable) {
        const variableSpanElement = this.renderer.createElement('span');
        this.renderer.setAttribute(variableSpanElement, 'yuz-var', variable.key);
        this.renderer.addClass(variableSpanElement, 'yuz-var');
        const userSelection = window.getSelection();
        const selectedTextRange = userSelection.getRangeAt(0);
        selectedTextRange.surroundContents(variableSpanElement);
        variableSpanElement.innerHTML = variable.value;
        const preSpan = this.renderer.createElement('span');
        const postSpan = this.renderer.createElement('span');
        variableSpanElement.before(preSpan);
        variableSpanElement.after(postSpan);
        preSpan.innerHTML = '&#8203;';
        postSpan.innerHTML = '&#8203;';
        var range = document.createRange();
        range.setStartBefore(preSpan);
        range.setEndAfter(postSpan);
        userSelection.removeAllRanges();
        userSelection.addRange(range);
    }
    selectVariable(variableSpanElement) {
        var range = document.createRange();
        range.setStartAfter(variableSpanElement.previousSibling);
        range.setEnd(variableSpanElement.nextSibling, 1);
        // range.setStartAfter(variableSpanElement.previousSibling);
        // range.setStart(range.startContainer, range.startOffset - 1);
        // range.setEndBefore(variableSpanElement.nextSibling);
        // range.setEnd(range.endContainer, range.endOffset + 11);
        const userSelection = window.getSelection();
        userSelection.removeAllRanges();
        userSelection.addRange(range);
        variableSpanElement.nextSibling;
    }
    /**
     * Create URL link
     * @param url string from UI prompt
     */
    createLink(url) {
        if (!url.includes('http')) {
            this.doc.execCommand('createlink', false, url);
        }
        else {
            const newUrl = '<a href="' + url + '" target="_blank">' + this.selectedText + '</a>';
            this.insertHtml(newUrl);
        }
    }
    /**
     * insert color either font or background
     *
     * @param color color to be inserted
     * @param where where the color has to be inserted either text/background
     */
    insertColor(color, where) {
        const restored = this.restoreSelection();
        if (restored) {
            if (where === 'textColor') {
                this.doc.execCommand('foreColor', false, color);
            }
            else {
                this.doc.execCommand('hiliteColor', false, color);
            }
        }
    }
    /**
     * Set font name
     * @param fontName string
     */
    setFontName(fontName) {
        this.doc.execCommand('fontName', false, fontName);
    }
    /**
     * Set font size
     * @param fontSize string
     */
    setFontSize(fontSize) {
        this.doc.execCommand('fontSize', false, fontSize);
    }
    /**
     * Create raw HTML
     * @param html HTML string
     */
    insertHtml(html) {
        const isHTMLInserted = this.doc.execCommand('insertHTML', false, html);
        if (!isHTMLInserted) {
            throw new Error('Unable to perform the operation');
        }
    }
    /**
     * restore selection when the editor is focused in
     *
     * saved selection when the editor is focused out
     */
    restoreSelection() {
        if (this.savedSelection) {
            if (this.doc.getSelection) {
                const sel = this.doc.getSelection();
                sel.removeAllRanges();
                sel.addRange(this.savedSelection);
                return true;
            }
            else if (this.doc.getSelection /*&& this.savedSelection.select*/) {
                // this.savedSelection.select();
                return true;
            }
        }
        else {
            return false;
        }
    }
    /**
     * setTimeout used for execute 'saveSelection' method in next event loop iteration
     */
    executeInNextQueueIteration(callbackFn, timeout = 1e2) {
        setTimeout(callbackFn, timeout);
    }
    /**
     * Upload file to uploadUrl
     * @param file The file
     */
    uploadImage(file) {
        const uploadData = new FormData();
        uploadData.append('file', file, file.name);
        return this.http.post(this.uploadUrl, uploadData, {
            reportProgress: true,
            observe: 'events',
            withCredentials: this.uploadWithCredentials,
        });
    }
    /**
     * Insert image with Url
     * @param imageUrl The imageUrl.
     */
    insertImage(imageUrl) {
        this.doc.execCommand('insertImage', false, imageUrl);
    }
    setDefaultParagraphSeparator(separator) {
        this.doc.execCommand('defaultParagraphSeparator', false, separator);
    }
    createCustomClass(customClass) {
        let newTag = this.selectedText;
        if (customClass) {
            const tagName = customClass.tag ? customClass.tag : 'span';
            newTag = '<' + tagName + ' class="' + customClass.class + '">' + this.selectedText + '</' + tagName + '>';
        }
        this.insertHtml(newTag);
    }
    insertVideo(videoUrl) {
        if (videoUrl.match('www.youtube.com')) {
            this.insertYouTubeVideoTag(videoUrl);
        }
        if (videoUrl.match('vimeo.com')) {
            this.insertVimeoVideoTag(videoUrl);
        }
    }
    insertYouTubeVideoTag(videoUrl) {
        const id = videoUrl.split('v=')[1];
        const imageUrl = `https://img.youtube.com/vi/${id}/0.jpg`;
        const thumbnail = `
      <div style='position: relative'>
        <img style='position: absolute; left:200px; top:140px'
             src="https://img.icons8.com/color/96/000000/youtube-play.png"/>
        <a href='${videoUrl}' target='_blank'>
          <img src="${imageUrl}" alt="click to watch"/>
        </a>
      </div>`;
        this.insertHtml(thumbnail);
    }
    insertVimeoVideoTag(videoUrl) {
        const sub = this.http.get(`https://vimeo.com/api/oembed.json?url=${videoUrl}`).subscribe((data) => {
            const imageUrl = data.thumbnail_url_with_play_button;
            const thumbnail = `<div>
        <a href='${videoUrl}' target='_blank'>
          <img src="${imageUrl}" alt="${data.title}"/>
        </a>
      </div>`;
            this.insertHtml(thumbnail);
            sub.unsubscribe();
        });
    }
    nextNode(node) {
        if (node.hasChildNodes()) {
            return node.firstChild;
        }
        else {
            while (node && !node.nextSibling) {
                node = node.parentNode;
            }
            if (!node) {
                return null;
            }
            return node.nextSibling;
        }
    }
    getRangeSelectedNodes(range, includePartiallySelectedContainers) {
        let node = range.startContainer;
        const endNode = range.endContainer;
        let rangeNodes = [];
        // Special case for a range that is contained within a single node
        if (node === endNode) {
            rangeNodes = [node];
        }
        else {
            // Iterate nodes until we hit the end container
            while (node && node !== endNode) {
                rangeNodes.push((node = this.nextNode(node)));
            }
            // Add partially selected nodes at the start of the range
            node = range.startContainer;
            while (node && node !== range.commonAncestorContainer) {
                rangeNodes.unshift(node);
                node = node.parentNode;
            }
        }
        // Add ancestors of the range container, if required
        if (includePartiallySelectedContainers) {
            node = range.commonAncestorContainer;
            while (node) {
                rangeNodes.push(node);
                node = node.parentNode;
            }
        }
        return rangeNodes;
    }
    getSelectedNodes() {
        const nodes = [];
        if (this.doc.getSelection) {
            const sel = this.doc.getSelection();
            for (let i = 0, len = sel.rangeCount; i < len; ++i) {
                nodes.push.apply(nodes, this.getRangeSelectedNodes(sel.getRangeAt(i), true));
            }
        }
        return nodes;
    }
    replaceWithOwnChildren(el) {
        const parent = el.parentNode;
        while (el.hasChildNodes()) {
            parent.insertBefore(el.firstChild, el);
        }
        parent.removeChild(el);
    }
    removeSelectedElements(tagNames) {
        const tagNamesArray = tagNames.toLowerCase().split(',');
        this.getSelectedNodes().forEach((node) => {
            if (node.nodeType === 1 && tagNamesArray.indexOf(node.tagName.toLowerCase()) > -1) {
                // Remove the node and replace it with its children
                this.replaceWithOwnChildren(node);
            }
        });
    }
}
AngularEditorService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.0", ngImport: i0, type: AngularEditorService, deps: [{ token: i1.HttpClient }, { token: DOCUMENT }, { token: i0.RendererFactory2 }], target: i0.ɵɵFactoryTarget.Injectable });
AngularEditorService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.0", ngImport: i0, type: AngularEditorService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.0", ngImport: i0, type: AngularEditorService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: function () {
        return [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                        type: Inject,
                        args: [DOCUMENT]
                    }] }, { type: i0.RendererFactory2 }];
    } });

const angularEditorConfig = {
    editable: true,
    spellcheck: true,
    height: 'auto',
    minHeight: '0',
    maxHeight: 'auto',
    width: 'auto',
    minWidth: '0',
    translate: 'yes',
    enableToolbar: true,
    showToolbar: true,
    placeholder: 'Enter text here...',
    defaultParagraphSeparator: '',
    defaultFontName: '',
    defaultFontSize: '',
    fonts: [
        { class: 'arial', name: 'Arial' },
        { class: 'times-new-roman', name: 'Times New Roman' },
        { class: 'calibri', name: 'Calibri' },
        { class: 'comic-sans-ms', name: 'Comic Sans MS' },
    ],
    uploadUrl: 'v1/image',
    uploadWithCredentials: false,
    sanitize: true,
    toolbarPosition: 'top',
    outline: true,
    /*toolbarHiddenButtons: [
      ['bold', 'italic', 'underline', 'strikeThrough', 'superscript', 'subscript'],
      ['heading', 'fontName', 'fontSize', 'color'],
      ['justifyLeft', 'justifyCenter', 'justifyRight', 'justifyFull', 'indent', 'outdent'],
      ['cut', 'copy', 'delete', 'removeFormat', 'undo', 'redo'],
      ['paragraph', 'blockquote', 'removeBlockquote', 'horizontalLine', 'orderedList', 'unorderedList'],
      ['link', 'unlink', 'image', 'video']
    ]*/
};

class Positioning {
    getAllStyles(element) {
        return window.getComputedStyle(element);
    }
    getStyle(element, prop) {
        return this.getAllStyles(element)[prop];
    }
    isStaticPositioned(element) {
        return (this.getStyle(element, 'position') || 'static') === 'static';
    }
    offsetParent(element) {
        let offsetParentEl = element.offsetParent || document.documentElement;
        while (offsetParentEl && offsetParentEl !== document.documentElement && this.isStaticPositioned(offsetParentEl)) {
            offsetParentEl = offsetParentEl.offsetParent;
        }
        return offsetParentEl || document.documentElement;
    }
    position(element, round = true) {
        let elPosition;
        let parentOffset = { width: 0, height: 0, top: 0, bottom: 0, left: 0, right: 0 };
        if (this.getStyle(element, 'position') === 'fixed') {
            const boundingRect = element.getBoundingClientRect();
            elPosition = {
                top: boundingRect.top,
                bottom: boundingRect.bottom,
                left: boundingRect.left,
                right: boundingRect.right,
                height: boundingRect.height,
                width: boundingRect.width,
            };
        }
        else {
            const offsetParentEl = this.offsetParent(element);
            elPosition = this.offset(element, false);
            if (offsetParentEl !== document.documentElement) {
                parentOffset = this.offset(offsetParentEl, false);
            }
            parentOffset.top += offsetParentEl.clientTop;
            parentOffset.left += offsetParentEl.clientLeft;
        }
        elPosition.top -= parentOffset.top;
        elPosition.bottom -= parentOffset.top;
        elPosition.left -= parentOffset.left;
        elPosition.right -= parentOffset.left;
        if (round) {
            elPosition.top = Math.round(elPosition.top);
            elPosition.bottom = Math.round(elPosition.bottom);
            elPosition.left = Math.round(elPosition.left);
            elPosition.right = Math.round(elPosition.right);
        }
        return elPosition;
    }
    offset(element, round = true) {
        const elBcr = element.getBoundingClientRect();
        const viewportOffset = {
            top: window.pageYOffset - document.documentElement.clientTop,
            left: window.pageXOffset - document.documentElement.clientLeft,
        };
        let elOffset = {
            height: elBcr.height || element.offsetHeight,
            width: elBcr.width || element.offsetWidth,
            top: elBcr.top + viewportOffset.top,
            bottom: elBcr.bottom + viewportOffset.top,
            left: elBcr.left + viewportOffset.left,
            right: elBcr.right + viewportOffset.left,
        };
        if (round) {
            elOffset.height = Math.round(elOffset.height);
            elOffset.width = Math.round(elOffset.width);
            elOffset.top = Math.round(elOffset.top);
            elOffset.bottom = Math.round(elOffset.bottom);
            elOffset.left = Math.round(elOffset.left);
            elOffset.right = Math.round(elOffset.right);
        }
        return elOffset;
    }
    /*
      Return false if the element to position is outside the viewport
    */
    positionElements(hostElement, targetElement, placement, appendToBody) {
        const [placementPrimary = 'top', placementSecondary = 'center'] = placement.split('-');
        const hostElPosition = appendToBody ? this.offset(hostElement, false) : this.position(hostElement, false);
        const targetElStyles = this.getAllStyles(targetElement);
        const marginTop = parseFloat(targetElStyles.marginTop);
        const marginBottom = parseFloat(targetElStyles.marginBottom);
        const marginLeft = parseFloat(targetElStyles.marginLeft);
        const marginRight = parseFloat(targetElStyles.marginRight);
        let topPosition = 0;
        let leftPosition = 0;
        switch (placementPrimary) {
            case 'top':
                topPosition = hostElPosition.top - (targetElement.offsetHeight + marginTop + marginBottom);
                break;
            case 'bottom':
                topPosition = hostElPosition.top + hostElPosition.height;
                break;
            case 'left':
                leftPosition = hostElPosition.left - (targetElement.offsetWidth + marginLeft + marginRight);
                break;
            case 'right':
                leftPosition = hostElPosition.left + hostElPosition.width;
                break;
        }
        switch (placementSecondary) {
            case 'top':
                topPosition = hostElPosition.top;
                break;
            case 'bottom':
                topPosition = hostElPosition.top + hostElPosition.height - targetElement.offsetHeight;
                break;
            case 'left':
                leftPosition = hostElPosition.left;
                break;
            case 'right':
                leftPosition = hostElPosition.left + hostElPosition.width - targetElement.offsetWidth;
                break;
            case 'center':
                if (placementPrimary === 'top' || placementPrimary === 'bottom') {
                    leftPosition = hostElPosition.left + hostElPosition.width / 2 - targetElement.offsetWidth / 2;
                }
                else {
                    topPosition = hostElPosition.top + hostElPosition.height / 2 - targetElement.offsetHeight / 2;
                }
                break;
        }
        /// The translate3d/gpu acceleration render a blurry text on chrome, the next line is commented until a browser fix
        // targetElement.style.transform = `translate3d(${Math.round(leftPosition)}px, ${Math.floor(topPosition)}px, 0px)`;
        targetElement.style.transform = `translate(${Math.round(leftPosition)}px, ${Math.round(topPosition)}px)`;
        // Check if the targetElement is inside the viewport
        const targetElBCR = targetElement.getBoundingClientRect();
        const html = document.documentElement;
        const windowHeight = window.innerHeight || html.clientHeight;
        const windowWidth = window.innerWidth || html.clientWidth;
        return targetElBCR.left >= 0 && targetElBCR.top >= 0 && targetElBCR.right <= windowWidth && targetElBCR.bottom <= windowHeight;
    }
}
const placementSeparator = /\s+/;
const positionService = new Positioning();
/*
 * Accept the placement array and applies the appropriate placement dependent on the viewport.
 * Returns the applied placement.
 * In case of auto placement, placements are selected in order
 *   'top', 'bottom', 'left', 'right',
 *   'top-left', 'top-right',
 *   'bottom-left', 'bottom-right',
 *   'left-top', 'left-bottom',
 *   'right-top', 'right-bottom'.
 * */
function positionElements(hostElement, targetElement, placement, appendToBody, baseClass) {
    let placementVals = Array.isArray(placement) ? placement : placement.split(placementSeparator);
    const allowedPlacements = [
        'top',
        'bottom',
        'left',
        'right',
        'top-left',
        'top-right',
        'bottom-left',
        'bottom-right',
        'left-top',
        'left-bottom',
        'right-top',
        'right-bottom',
    ];
    const classList = targetElement.classList;
    const addClassesToTarget = (targetPlacement) => {
        const [primary, secondary] = targetPlacement.split('-');
        const classes = [];
        if (baseClass) {
            classes.push(`${baseClass}-${primary}`);
            if (secondary) {
                classes.push(`${baseClass}-${primary}-${secondary}`);
            }
            classes.forEach((classname) => {
                classList.add(classname);
            });
        }
        return classes;
    };
    // Remove old placement classes to avoid issues
    if (baseClass) {
        allowedPlacements.forEach((placementToRemove) => {
            classList.remove(`${baseClass}-${placementToRemove}`);
        });
    }
    // replace auto placement with other placements
    let hasAuto = placementVals.findIndex((val) => val === 'auto');
    if (hasAuto >= 0) {
        allowedPlacements.forEach(function (obj) {
            if (placementVals.find((val) => val.search('^' + obj) !== -1) == null) {
                placementVals.splice(hasAuto++, 1, obj);
            }
        });
    }
    // coordinates where to position
    // Required for transform:
    const style = targetElement.style;
    style.position = 'absolute';
    style.top = '0';
    style.left = '0';
    style['will-change'] = 'transform';
    let testPlacement = null;
    let isInViewport = false;
    for (testPlacement of placementVals) {
        let addedClasses = addClassesToTarget(testPlacement);
        if (positionService.positionElements(hostElement, targetElement, testPlacement, appendToBody)) {
            isInViewport = true;
            break;
        }
        // Remove the baseClasses for further calculation
        if (baseClass) {
            addedClasses.forEach((classname) => {
                classList.remove(classname);
            });
        }
    }
    if (!isInViewport) {
        // If nothing match, the first placement is the default one
        testPlacement = placementVals[0];
        addClassesToTarget(testPlacement);
        positionService.positionElements(hostElement, targetElement, testPlacement, appendToBody);
    }
    return testPlacement;
}

function isDefined(value) {
    return value !== undefined && value !== null;
}

class AeSelectComponent {
    constructor(elRef, r) {
        this.elRef = elRef;
        this.r = r;
        this.options = [];
        this.disabled = false;
        this.optionId = 0;
        this.opened = false;
        this.hidden = 'inline-block';
        // tslint:disable-next-line:no-output-native no-output-rename
        this.changeEvent = new EventEmitter();
        this.onChange = () => { };
        this.onTouched = () => { };
    }
    get label() {
        return this.selectedOption && this.selectedOption.hasOwnProperty('label') ? this.selectedOption.label : 'Select';
    }
    get value() {
        return this.selectedOption.value;
    }
    ngOnInit() {
        this.selectedOption = this.options[0];
        if (isDefined(this.isHidden) && this.isHidden) {
            this.hide();
        }
    }
    hide() {
        this.hidden = 'none';
    }
    optionSelect(option, event) {
        event.stopPropagation();
        this.setValue(option.value);
        this.onChange(this.selectedOption.value);
        this.changeEvent.emit(this.selectedOption.value);
        this.onTouched();
        this.opened = false;
    }
    toggleOpen(event) {
        //event.stopPropagation();
        if (this.disabled) {
            return;
        }
        this.opened = !this.opened;
    }
    onClick($event) {
        if (!this.elRef.nativeElement.contains($event.target)) {
            this.close();
        }
    }
    close() {
        this.opened = false;
    }
    get isOpen() {
        return this.opened;
    }
    writeValue(value) {
        if (!value || typeof value !== 'string') {
            return;
        }
        this.setValue(value);
    }
    setValue(value) {
        let index = 0;
        const selectedEl = this.options.find((el, i) => {
            index = i;
            return el.value === value;
        });
        if (selectedEl) {
            this.selectedOption = selectedEl;
            this.optionId = index;
        }
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    setDisabledState(isDisabled) {
        this.labelButton.nativeElement.disabled = isDisabled;
        const div = this.labelButton.nativeElement;
        const action = isDisabled ? 'addClass' : 'removeClass';
        this.r[action](div, 'disabled');
        this.disabled = isDisabled;
    }
    handleKeyDown($event) {
        if (!this.opened) {
            return;
        }
        // console.log($event.key);
        // if (KeyCode[$event.key]) {
        switch ($event.key) {
            case 'ArrowDown':
                this._handleArrowDown($event);
                break;
            case 'ArrowUp':
                this._handleArrowUp($event);
                break;
            case 'Space':
                this._handleSpace($event);
                break;
            case 'Enter':
                this._handleEnter($event);
                break;
            case 'Tab':
                this._handleTab($event);
                break;
            case 'Escape':
                this.close();
                $event.preventDefault();
                break;
            case 'Backspace':
                this._handleBackspace();
                break;
        }
        // } else if ($event.key && $event.key.length === 1) {
        // this._keyPress$.next($event.key.toLocaleLowerCase());
        // }
    }
    _handleArrowDown($event) {
        if (this.optionId < this.options.length - 1) {
            this.optionId++;
        }
    }
    _handleArrowUp($event) {
        if (this.optionId >= 1) {
            this.optionId--;
        }
    }
    _handleSpace($event) { }
    _handleEnter($event) {
        this.optionSelect(this.options[this.optionId], $event);
    }
    _handleTab($event) { }
    _handleBackspace() { }
}
AeSelectComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.0", ngImport: i0, type: AeSelectComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Component });
AeSelectComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.0", type: AeSelectComponent, selector: "ae-select", inputs: { options: "options", isHidden: ["hidden", "isHidden"], selectBtnClass: "selectBtnClass" }, outputs: { changeEvent: "change" }, host: { listeners: { "document:click": "onClick($event)", "keydown": "handleKeyDown($event)" }, properties: { "style.display": "this.hidden" } }, providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => AeSelectComponent),
            multi: true,
        },
    ], viewQueries: [{ propertyName: "labelButton", first: true, predicate: ["labelButton"], descendants: true, static: true }], ngImport: i0, template: "<div ngbDropdown>\n  <button ngbDropdownToggle type=\"button\" role=\"button\" id=\"selectDropDown\" [class]=\"selectBtnClass\">\n    {{label}}\n  </button>\n  <div ngbDropdownMenu aria-labelledby=\"dropdownBasic1\">\n    <button ngbDropdownItem type=\"button\" role=\"button\" *ngFor=\"let item of options; let i = index\"\n      (click)=\"optionSelect(item, $event)\"\n      [ngClass]=\"{'selected': item.value === value, 'focused': i === optionId}\">\n      {{item.label}}\n    </button>\n    <div class=\"dropdown-item\" *ngIf=\"!options.length\">No items for select</div>\n  </div>\n</div>", directives: [{ type: i1$1.NgbDropdown, selector: "[ngbDropdown]", inputs: ["autoClose", "dropdownClass", "open", "placement", "container", "display"], outputs: ["openChange"], exportAs: ["ngbDropdown"] }, { type: i1$1.NgbDropdownToggle, selector: "[ngbDropdownToggle]" }, { type: i1$1.NgbDropdownMenu, selector: "[ngbDropdownMenu]" }, { type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i1$1.NgbDropdownItem, selector: "[ngbDropdownItem]", inputs: ["disabled"] }, { type: i4.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }], encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.0", ngImport: i0, type: AeSelectComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ae-select', encapsulation: ViewEncapsulation.None, providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => AeSelectComponent),
                            multi: true,
                        },
                    ], template: "<div ngbDropdown>\n  <button ngbDropdownToggle type=\"button\" role=\"button\" id=\"selectDropDown\" [class]=\"selectBtnClass\">\n    {{label}}\n  </button>\n  <div ngbDropdownMenu aria-labelledby=\"dropdownBasic1\">\n    <button ngbDropdownItem type=\"button\" role=\"button\" *ngFor=\"let item of options; let i = index\"\n      (click)=\"optionSelect(item, $event)\"\n      [ngClass]=\"{'selected': item.value === value, 'focused': i === optionId}\">\n      {{item.label}}\n    </button>\n    <div class=\"dropdown-item\" *ngIf=\"!options.length\">No items for select</div>\n  </div>\n</div>" }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }]; }, propDecorators: { options: [{
                type: Input
            }], isHidden: [{
                type: Input,
                args: ['hidden']
            }], selectBtnClass: [{
                type: Input
            }], hidden: [{
                type: HostBinding,
                args: ['style.display']
            }], changeEvent: [{
                type: Output,
                args: ['change']
            }], labelButton: [{
                type: ViewChild,
                args: ['labelButton', { static: true }]
            }], onClick: [{
                type: HostListener,
                args: ['document:click', ['$event']]
            }], handleKeyDown: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }] } });

class AngularEditorToolbarComponent {
    constructor(r, editorService, doc, elementRef) {
        this.r = r;
        this.editorService = editorService;
        this.doc = doc;
        this.textColorToggle = false;
        this.textColor = '#000';
        this.backgroundColorToggle = false;
        this.backgroundColor = '#000000ff';
        this.htmlMode = false;
        this.linkSelected = false;
        this.block = 'default';
        this.fontName = 'Times New Roman';
        this.fontSize = '3';
        this.variables = [
            {
                label: 'Family name',
                value: 'familyName',
            },
            {
                label: 'Given name',
                value: 'givenName',
            },
        ];
        this.headings = [
            {
                label: 'Heading 1',
                value: 'h1',
            },
            {
                label: 'Heading 2',
                value: 'h2',
            },
            {
                label: 'Heading 3',
                value: 'h3',
            },
            {
                label: 'Heading 4',
                value: 'h4',
            },
            {
                label: 'Heading 5',
                value: 'h5',
            },
            {
                label: 'Heading 6',
                value: 'h6',
            },
            {
                label: 'Heading 7',
                value: 'h7',
            },
            {
                label: 'Paragraph',
                value: 'p',
            },
            {
                label: 'Predefined',
                value: 'pre',
            },
            {
                label: 'Standard',
                value: 'div',
            },
            {
                label: 'default',
                value: 'default',
            },
        ];
        this.fontSizes = [
            {
                label: '1',
                value: '1',
            },
            {
                label: '2',
                value: '2',
            },
            {
                label: '3',
                value: '3',
            },
            {
                label: '4',
                value: '4',
            },
            {
                label: '5',
                value: '5',
            },
            {
                label: '6',
                value: '6',
            },
            {
                label: '7',
                value: '7',
            },
        ];
        this.customClassId = '-1';
        this.customClassList = [{ label: '', value: '' }];
        // uploadUrl: string;
        this.tagMap = {
            BLOCKQUOTE: 'indent',
            A: 'link',
        };
        this.select = ['H1', 'H2', 'H3', 'H4', 'H5', 'H6', 'P', 'PRE', 'DIV'];
        this.buttons = [
            'bold',
            'italic',
            'underline',
            'strikeThrough',
            'subscript',
            'superscript',
            'justifyLeft',
            'justifyCenter',
            'justifyRight',
            'justifyFull',
            'indent',
            'outdent',
            'insertUnorderedList',
            'insertOrderedList',
            'link',
        ];
        this.fonts = [{ label: '', value: '' }];
        this.execute = new EventEmitter();
        this.nativeElement = elementRef.nativeElement;
    }
    set customClasses(classes) {
        if (classes) {
            this._customClasses = classes;
            this.customClassList = this._customClasses.map((x, i) => ({ label: x.name, value: i.toString() }));
            this.customClassList.unshift({ label: 'Clear Class', value: '-1' });
        }
    }
    set defaultFontName(value) {
        if (value) {
            this.fontName = value;
        }
    }
    set defaultFontSize(value) {
        if (value) {
            this.fontSize = value;
        }
    }
    get isLinkButtonDisabled() {
        return this.htmlMode || !Boolean(this.editorService.selectedText);
    }
    ngOnInit() {
        this.activeButtons = this.buttons.filter((it) => !this.isButtonHidden(it));
        this.toolbarBgClass = this.toolbarBgClass ? this.toolbarBgClass : '';
        this.toolbarBtnClass = this.toolbarBtnClass ? this.toolbarBtnClass : 'btn btn-light';
    }
    /**
     * Trigger command from editor header buttons
     * @param command string from toolbar buttons
     */
    triggerCommand(command) {
        this.execute.emit(command);
    }
    /**
     * highlight editor buttons when cursor moved or positioning
     */
    triggerButtons() {
        if (!this.showToolbar) {
            return;
        }
        this.activeButtons.forEach((e) => {
            const result = this.doc.queryCommandState(e);
            const elementById = this.doc.getElementById(e + '-' + this.id);
            if (result) {
                this.r.addClass(elementById, 'active');
            }
            else {
                this.r.removeClass(elementById, 'active');
            }
        });
    }
    /**
     * trigger highlight editor buttons when cursor moved or positioning in block
     */
    triggerBlocks(nodes) {
        if (!this.showToolbar) {
            return;
        }
        this.linkSelected = nodes.findIndex((x) => x.nodeName === 'A') > -1;
        const variableNode = nodes.find((it) => { var _a; return !!((_a = it.attributes) === null || _a === void 0 ? void 0 : _a.getNamedItem('yuz-var')); });
        if (variableNode) {
            this.editorService.selectVariable(variableNode);
        }
        let found = false;
        this.select.forEach((y) => {
            const node = nodes.find((x) => x.nodeName === y);
            if (node !== undefined && y === node.nodeName) {
                if (found === false) {
                    this.block = node.nodeName.toLowerCase();
                    found = true;
                }
            }
            else if (found === false) {
                this.block = 'default';
            }
        });
        found = false;
        if (this._customClasses) {
            this._customClasses.forEach((y, index) => {
                const node = nodes.find((x) => {
                    if (x instanceof Element) {
                        return x.className === y.class;
                    }
                });
                if (node !== undefined) {
                    if (found === false) {
                        this.customClassId = index.toString();
                        found = true;
                    }
                }
                else if (found === false) {
                    this.customClassId = '-1';
                }
            });
        }
        Object.keys(this.tagMap).map((e) => {
            const elementById = this.doc.getElementById(this.tagMap[e] + '-' + this.id);
            const node = nodes.find((x) => x.nodeName === e);
            if (node !== undefined && e === node.nodeName) {
                this.r.addClass(elementById, 'active');
            }
            else {
                this.r.removeClass(elementById, 'active');
            }
        });
        this.foreColour = this.doc.queryCommandValue('ForeColor');
        this.fontSize = this.doc.queryCommandValue('FontSize');
        this.fontName = this.doc.queryCommandValue('FontName').replace(/"/g, '');
        this.backColor = this.doc.queryCommandValue('backColor');
    }
    insertVariable(selectValue) {
        const variable = this.variables.find((it) => it.value === selectValue);
        if (variable) {
            this.editorService.insertVariable({
                key: variable.value,
                value: variable.label,
            });
        }
        this.execute.emit('contentChange');
    }
    /**
     * insert URL link
     */
    insertUrl() {
        let url = 'https://';
        const selection = this.editorService.savedSelection;
        if (selection && selection.commonAncestorContainer.parentElement.nodeName === 'A') {
            const parent = selection.commonAncestorContainer.parentElement;
            if (parent.href !== '') {
                url = parent.href;
            }
        }
        url = prompt('Insert URL link', url);
        if (url && url !== '' && url !== 'https://') {
            this.editorService.createLink(url);
        }
    }
    /**
     * insert Video link
     */
    insertVideo() {
        this.execute.emit('');
        const url = prompt('Insert Video link', `https://`);
        if (url && url !== '' && url !== `https://`) {
            this.editorService.insertVideo(url);
        }
    }
    /** insert color */
    insertColor(color, where) {
        this.editorService.insertColor(color, where);
        this.execute.emit('');
    }
    /**
     * set font Name/family
     * @param foreColor string
     */
    setFontName(foreColor) {
        this.editorService.setFontName(foreColor);
        this.execute.emit('');
    }
    /**
     * set font Size
     * @param fontSize string
     */
    setFontSize(fontSize) {
        this.editorService.setFontSize(fontSize);
        this.execute.emit('');
    }
    /**
     * toggle editor mode (WYSIWYG or SOURCE)
     * @param m boolean
     */
    setEditorMode(m) {
        const toggleEditorModeButton = this.doc.getElementById('toggleEditorMode' + '-' + this.id);
        if (m) {
            this.r.addClass(toggleEditorModeButton, 'active');
        }
        else {
            this.r.removeClass(toggleEditorModeButton, 'active');
        }
        this.htmlMode = m;
    }
    /**
     * Upload image when file is selected
     */
    onFileChanged(event) {
        const file = event.target.files[0];
        if (file.type.includes('image/')) {
            if (this.uploadUrl) {
                this.editorService.uploadImage(file).subscribe((e) => {
                    if (e instanceof HttpResponse) {
                        this.editorService.insertImage(e.body.imageUrl);
                        event.srcElement.value = null;
                    }
                });
            }
            else {
                const reader = new FileReader();
                reader.onload = (e) => {
                    const fr = e.currentTarget;
                    this.editorService.insertImage(fr.result.toString());
                };
                reader.readAsDataURL(file);
            }
        }
    }
    /**
     * Set custom class
     */
    setCustomClass(classId) {
        if (classId === '-1') {
            this.execute.emit('clear');
        }
        else {
            this.editorService.createCustomClass(this._customClasses[+classId]);
        }
    }
    isButtonHidden(name) {
        if (!name) {
            return false;
        }
        if (!(this.hiddenButtons instanceof Array)) {
            return false;
        }
        let result;
        for (const arr of this.hiddenButtons) {
            if (arr instanceof Array) {
                result = arr.find((item) => item === name);
            }
            if (result) {
                break;
            }
        }
        return result !== undefined;
    }
}
AngularEditorToolbarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.0", ngImport: i0, type: AngularEditorToolbarComponent, deps: [{ token: i0.Renderer2 }, { token: AngularEditorService }, { token: DOCUMENT }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
AngularEditorToolbarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.0", type: AngularEditorToolbarComponent, selector: "angular-editor-toolbar", inputs: { id: "id", uploadUrl: "uploadUrl", showToolbar: "showToolbar", fonts: "fonts", toolbarBgClass: "toolbarBgClass", toolbarBtnClass: "toolbarBtnClass", customButtons: "customButtons", customClasses: "customClasses", defaultFontName: "defaultFontName", defaultFontSize: "defaultFontSize", hiddenButtons: "hiddenButtons" }, outputs: { execute: "execute" }, viewQueries: [{ propertyName: "myInputFile", first: true, predicate: ["fileInput"], descendants: true, static: true }], ngImport: i0, template: "<div *ngIf=\"showToolbar\" [class]=\"toolbarBgClass\">\n  <div class=\"btn-group m-1\">\n    <button\n      type=\"button\"\n      title=\"Undo\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('undo')\"\n      [hidden]=\"isButtonHidden('undo')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'undo']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      type=\"button\"\n      title=\"Redo\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('redo')\"\n      [hidden]=\"isButtonHidden('redo')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'redo']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n  </div>\n  <div class=\"btn-group m-1\">\n    <button\n      [id]=\"'bold-' + id\"\n      type=\"button\"\n      title=\"Bold\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('bold')\"\n      [disabled]=\"htmlMode\"\n      *ngIf=\"!isButtonHidden('bold')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'bold']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'italic-' + id\"\n      type=\"button\"\n      title=\"Italic\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('italic')\"\n      [disabled]=\"htmlMode\"\n      *ngIf=\"!isButtonHidden('italic')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'italic']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'underline-' + id\"\n      type=\"button\"\n      title=\"Underline\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('underline')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('underline')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'underline']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'strikeThrough-' + id\"\n      type=\"button\"\n      title=\"Strikethrough\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('strikeThrough')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('strikeThrough')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'strikethrough']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'subscript-' + id\"\n      type=\"button\"\n      title=\"Subscript\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('subscript')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('subscript')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'subscript']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'superscript-' + id\"\n      type=\"button\"\n      title=\"Superscript\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('superscript')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('superscript')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'superscript']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n  </div>\n  <div class=\"btn-group m-1\">\n    <button\n      [id]=\"'justifyLeft-' + id\"\n      type=\"button\"\n      title=\"Justify Left\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('justifyLeft')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('justifyLeft')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'align-left']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'justifyCenter-' + id\"\n      type=\"button\"\n      title=\"Justify Center\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('justifyCenter')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('justifyCenter')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'align-center']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'justifyRight-' + id\"\n      type=\"button\"\n      title=\"Justify Right\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('justifyRight')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('justifyRight')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'align-right']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'justifyFull-' + id\"\n      type=\"button\"\n      title=\"Justify Full\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('justifyFull')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('justifyFull')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'align-justify']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n  </div>\n  <div class=\"btn-group m-1\">\n    <button\n      [id]=\"'indent-' + id\"\n      type=\"button\"\n      title=\"Indent\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('indent')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('indent')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'indent']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'outdent-' + id\"\n      type=\"button\"\n      title=\"Outdent\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('outdent')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('outdent')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'outdent']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n  </div>\n  <div class=\"btn-group m-1\">\n    <button\n      [id]=\"'insertUnorderedList-' + id\"\n      type=\"button\"\n      title=\"Unordered List\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('insertUnorderedList')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('insertUnorderedList')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'list-ul']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'insertOrderedList-' + id\"\n      type=\"button\"\n      title=\"Ordered List\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('insertOrderedList')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('insertOrderedList')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'list-ol']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n  </div>\n  <div class=\"btn-group m-1\">\n    <ae-select\n      class=\"select-heading\"\n      [selectBtnClass]=\"toolbarBtnClass\"\n      [options]=\"headings\"\n      [(ngModel)]=\"block\"\n      (change)=\"triggerCommand(block)\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('heading')\"\n      tabindex=\"-1\"\n    ></ae-select>\n  </div>\n  <div class=\"btn-group m-1\">\n    <ae-select\n      class=\"select-font\"\n      [selectBtnClass]=\"toolbarBtnClass\"\n      [options]=\"fonts\"\n      [(ngModel)]=\"fontName\"\n      (change)=\"setFontName(fontName)\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('fontName')\"\n      tabindex=\"-1\"\n    ></ae-select>\n  </div>\n  <div [ngClass]=\"{ 'btn-group m-1': !isButtonHidden('fontSize') }\" [ngStyle]=\"{ display: 'inline-block' }\">\n    <ae-select\n      class=\"select-font-size\"\n      [selectBtnClass]=\"toolbarBtnClass\"\n      [options]=\"fontSizes\"\n      [(ngModel)]=\"fontSize\"\n      (change)=\"setFontSize(fontSize)\"\n      [hidden]=\"isButtonHidden('fontSize')\"\n      tabindex=\"-1\"\n    >\n    </ae-select>\n  </div>\n  <div class=\"btn-group m-1\">\n    <button\n      [id]=\"'foregroundColorPicker-' + id\"\n      type=\"button\"\n      [class]=\"toolbarBtnClass\"\n      [style.color]=\"textColor\"\n      (click)=\"textColorToggle = !textColorToggle\"\n      title=\"Text Color\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('textColor')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'font']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <input\n      #textColorInput\n      class=\"invisible\"\n      style=\"width: 0px !important; padding: 0px !important; border: none !important\"\n      [cpIgnoredElements]=\"[textColorInput]\"\n      [(cpToggle)]=\"textColorToggle\"\n      [(colorPicker)]=\"textColor\"\n      (colorPickerChange)=\"insertColor($event, 'textColor')\"\n    />\n    <button\n      [id]=\"'backgroundColorPicker-' + id\"\n      type=\"button\"\n      [class]=\"toolbarBtnClass\"\n      [style.color]=\"backgroundColor\"\n      (click)=\"backgroundColorToggle = !backgroundColorToggle\"\n      title=\"Background Color\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('backgroundColor')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'highlighter']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n  </div>\n  <!-- Place it after the btn group div so that it does not interfer with rounding. -->\n  <input\n    #backgroundColorInput\n    class=\"invisible\"\n    style=\"width: 0px !important; padding: 0px !important; border: none !important\"\n    [cpIgnoredElements]=\"[backgroundColorInput]\"\n    [(cpToggle)]=\"backgroundColorToggle\"\n    [(colorPicker)]=\"backgroundColor\"\n    (colorPickerChange)=\"insertColor($event, 'backgroundColor')\"\n  />\n  <div *ngIf=\"_customClasses\" class=\"btn-group m-1\">\n    <ae-select\n      class=\"select-custom-style\"\n      [selectBtnClass]=\"toolbarBtnClass\"\n      [options]=\"customClassList\"\n      [(ngModel)]=\"customClassId\"\n      (change)=\"setCustomClass(customClassId)\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('customClasses')\"\n      tabindex=\"-1\"\n    ></ae-select>\n  </div>\n  <div class=\"btn-group m-1\">\n    <ae-select\n      class=\"select-heading\"\n      [selectBtnClass]=\"toolbarBtnClass\"\n      [options]=\"variables\"\n      [(ngModel)]=\"variableName\"\n      (change)=\"insertVariable($event)\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('heading')\"\n      tabindex=\"-1\"\n    ></ae-select>\n  </div>\n  <div class=\"btn-group m-1\">\n    <button\n      [id]=\"'link-' + id\"\n      type=\"button\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"insertUrl()\"\n      title=\"Insert Link\"\n      [disabled]=\"isLinkButtonDisabled\"\n      [hidden]=\"isButtonHidden('link')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'link']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'unlink-' + id\"\n      type=\"button\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('unlink')\"\n      title=\"Unlink\"\n      [disabled]=\"htmlMode || !linkSelected\"\n      [hidden]=\"isButtonHidden('unlink')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'unlink']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <input style=\"display: none\" accept=\"image/*\" type=\"file\" (change)=\"onFileChanged($event)\" #fileInput />\n    <button\n      [id]=\"'insertImage-' + id\"\n      type=\"button\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"fileInput.click()\"\n      title=\"Insert Image\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('insertImage')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'image']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <ng-container *ngIf=\"customButtons\">\n      <button\n        *ngFor=\"let button of customButtons\"\n        [id]=\"button.customButtonId + '-' + id\"\n        type=\"button\"\n        [class]=\"toolbarBtnClass\"\n        (click)=\"button.onClick()\"\n        [disabled]=\"htmlMode\"\n        tabindex=\"-1\"\n      >\n        <fa-icon [icon]=\"button.faIcon\" [fixedWidth]=\"true\"></fa-icon>\n      </button>\n    </ng-container>\n    <button\n      [id]=\"'insertVideo-' + id\"\n      type=\"button\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"insertVideo()\"\n      title=\"Insert Video\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('insertVideo')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'video']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'insertHorizontalRule-' + id\"\n      type=\"button\"\n      title=\"Horizontal Line\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('insertHorizontalRule')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('insertHorizontalRule')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'minus']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n  </div>\n  <div class=\"btn-group m-1\">\n    <button\n      [id]=\"'clearFormatting-' + id\"\n      type=\"button\"\n      title=\"Clear Formatting\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('removeFormat')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('removeFormat')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'remove-format']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n  </div>\n  <div class=\"btn-group m-1\">\n    <button\n      [id]=\"'toggleEditorMode-' + id\"\n      type=\"button\"\n      title=\"HTML Code\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('toggleEditorMode')\"\n      [hidden]=\"isButtonHidden('toggleEditorMode')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'code']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n  </div>\n</div>\n", components: [{ type: i1$2.FaIconComponent, selector: "fa-icon", inputs: ["icon", "title", "spin", "pulse", "mask", "styles", "flip", "size", "pull", "border", "inverse", "symbol", "rotate", "fixedWidth", "classes", "transform", "a11yRole"] }, { type: AeSelectComponent, selector: "ae-select", inputs: ["options", "hidden", "selectBtnClass"], outputs: ["change"] }], directives: [{ type: i4.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i5.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { type: i5.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { type: i4.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i4.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { type: i6.ColorPickerDirective, selector: "[colorPicker]", inputs: ["colorPicker", "cpWidth", "cpHeight", "cpToggle", "cpDisabled", "cpIgnoredElements", "cpFallbackColor", "cpColorMode", "cpCmykEnabled", "cpOutputFormat", "cpAlphaChannel", "cpDisableInput", "cpDialogDisplay", "cpSaveClickOutside", "cpCloseClickOutside", "cpUseRootViewContainer", "cpPosition", "cpPositionOffset", "cpPositionRelativeToArrow", "cpOKButton", "cpOKButtonText", "cpOKButtonClass", "cpCancelButton", "cpCancelButtonText", "cpCancelButtonClass", "cpEyeDropper", "cpPresetLabel", "cpPresetColors", "cpPresetColorsClass", "cpMaxPresetColorsLength", "cpPresetEmptyMessage", "cpPresetEmptyMessageClass", "cpAddColorButton", "cpAddColorButtonText", "cpAddColorButtonClass", "cpRemoveColorButtonClass", "cpExtraTemplate"], outputs: ["cpInputChange", "cpToggleChange", "cpSliderChange", "cpSliderDragEnd", "cpSliderDragStart", "colorPickerOpen", "colorPickerClose", "colorPickerCancel", "colorPickerSelect", "colorPickerChange", "cpCmykColorChange", "cpPresetColorsChange"], exportAs: ["ngxColorPicker"] }, { type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.0", ngImport: i0, type: AngularEditorToolbarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'angular-editor-toolbar', template: "<div *ngIf=\"showToolbar\" [class]=\"toolbarBgClass\">\n  <div class=\"btn-group m-1\">\n    <button\n      type=\"button\"\n      title=\"Undo\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('undo')\"\n      [hidden]=\"isButtonHidden('undo')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'undo']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      type=\"button\"\n      title=\"Redo\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('redo')\"\n      [hidden]=\"isButtonHidden('redo')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'redo']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n  </div>\n  <div class=\"btn-group m-1\">\n    <button\n      [id]=\"'bold-' + id\"\n      type=\"button\"\n      title=\"Bold\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('bold')\"\n      [disabled]=\"htmlMode\"\n      *ngIf=\"!isButtonHidden('bold')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'bold']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'italic-' + id\"\n      type=\"button\"\n      title=\"Italic\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('italic')\"\n      [disabled]=\"htmlMode\"\n      *ngIf=\"!isButtonHidden('italic')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'italic']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'underline-' + id\"\n      type=\"button\"\n      title=\"Underline\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('underline')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('underline')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'underline']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'strikeThrough-' + id\"\n      type=\"button\"\n      title=\"Strikethrough\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('strikeThrough')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('strikeThrough')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'strikethrough']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'subscript-' + id\"\n      type=\"button\"\n      title=\"Subscript\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('subscript')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('subscript')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'subscript']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'superscript-' + id\"\n      type=\"button\"\n      title=\"Superscript\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('superscript')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('superscript')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'superscript']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n  </div>\n  <div class=\"btn-group m-1\">\n    <button\n      [id]=\"'justifyLeft-' + id\"\n      type=\"button\"\n      title=\"Justify Left\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('justifyLeft')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('justifyLeft')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'align-left']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'justifyCenter-' + id\"\n      type=\"button\"\n      title=\"Justify Center\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('justifyCenter')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('justifyCenter')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'align-center']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'justifyRight-' + id\"\n      type=\"button\"\n      title=\"Justify Right\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('justifyRight')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('justifyRight')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'align-right']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'justifyFull-' + id\"\n      type=\"button\"\n      title=\"Justify Full\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('justifyFull')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('justifyFull')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'align-justify']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n  </div>\n  <div class=\"btn-group m-1\">\n    <button\n      [id]=\"'indent-' + id\"\n      type=\"button\"\n      title=\"Indent\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('indent')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('indent')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'indent']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'outdent-' + id\"\n      type=\"button\"\n      title=\"Outdent\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('outdent')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('outdent')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'outdent']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n  </div>\n  <div class=\"btn-group m-1\">\n    <button\n      [id]=\"'insertUnorderedList-' + id\"\n      type=\"button\"\n      title=\"Unordered List\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('insertUnorderedList')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('insertUnorderedList')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'list-ul']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'insertOrderedList-' + id\"\n      type=\"button\"\n      title=\"Ordered List\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('insertOrderedList')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('insertOrderedList')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'list-ol']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n  </div>\n  <div class=\"btn-group m-1\">\n    <ae-select\n      class=\"select-heading\"\n      [selectBtnClass]=\"toolbarBtnClass\"\n      [options]=\"headings\"\n      [(ngModel)]=\"block\"\n      (change)=\"triggerCommand(block)\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('heading')\"\n      tabindex=\"-1\"\n    ></ae-select>\n  </div>\n  <div class=\"btn-group m-1\">\n    <ae-select\n      class=\"select-font\"\n      [selectBtnClass]=\"toolbarBtnClass\"\n      [options]=\"fonts\"\n      [(ngModel)]=\"fontName\"\n      (change)=\"setFontName(fontName)\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('fontName')\"\n      tabindex=\"-1\"\n    ></ae-select>\n  </div>\n  <div [ngClass]=\"{ 'btn-group m-1': !isButtonHidden('fontSize') }\" [ngStyle]=\"{ display: 'inline-block' }\">\n    <ae-select\n      class=\"select-font-size\"\n      [selectBtnClass]=\"toolbarBtnClass\"\n      [options]=\"fontSizes\"\n      [(ngModel)]=\"fontSize\"\n      (change)=\"setFontSize(fontSize)\"\n      [hidden]=\"isButtonHidden('fontSize')\"\n      tabindex=\"-1\"\n    >\n    </ae-select>\n  </div>\n  <div class=\"btn-group m-1\">\n    <button\n      [id]=\"'foregroundColorPicker-' + id\"\n      type=\"button\"\n      [class]=\"toolbarBtnClass\"\n      [style.color]=\"textColor\"\n      (click)=\"textColorToggle = !textColorToggle\"\n      title=\"Text Color\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('textColor')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'font']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <input\n      #textColorInput\n      class=\"invisible\"\n      style=\"width: 0px !important; padding: 0px !important; border: none !important\"\n      [cpIgnoredElements]=\"[textColorInput]\"\n      [(cpToggle)]=\"textColorToggle\"\n      [(colorPicker)]=\"textColor\"\n      (colorPickerChange)=\"insertColor($event, 'textColor')\"\n    />\n    <button\n      [id]=\"'backgroundColorPicker-' + id\"\n      type=\"button\"\n      [class]=\"toolbarBtnClass\"\n      [style.color]=\"backgroundColor\"\n      (click)=\"backgroundColorToggle = !backgroundColorToggle\"\n      title=\"Background Color\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('backgroundColor')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'highlighter']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n  </div>\n  <!-- Place it after the btn group div so that it does not interfer with rounding. -->\n  <input\n    #backgroundColorInput\n    class=\"invisible\"\n    style=\"width: 0px !important; padding: 0px !important; border: none !important\"\n    [cpIgnoredElements]=\"[backgroundColorInput]\"\n    [(cpToggle)]=\"backgroundColorToggle\"\n    [(colorPicker)]=\"backgroundColor\"\n    (colorPickerChange)=\"insertColor($event, 'backgroundColor')\"\n  />\n  <div *ngIf=\"_customClasses\" class=\"btn-group m-1\">\n    <ae-select\n      class=\"select-custom-style\"\n      [selectBtnClass]=\"toolbarBtnClass\"\n      [options]=\"customClassList\"\n      [(ngModel)]=\"customClassId\"\n      (change)=\"setCustomClass(customClassId)\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('customClasses')\"\n      tabindex=\"-1\"\n    ></ae-select>\n  </div>\n  <div class=\"btn-group m-1\">\n    <ae-select\n      class=\"select-heading\"\n      [selectBtnClass]=\"toolbarBtnClass\"\n      [options]=\"variables\"\n      [(ngModel)]=\"variableName\"\n      (change)=\"insertVariable($event)\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('heading')\"\n      tabindex=\"-1\"\n    ></ae-select>\n  </div>\n  <div class=\"btn-group m-1\">\n    <button\n      [id]=\"'link-' + id\"\n      type=\"button\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"insertUrl()\"\n      title=\"Insert Link\"\n      [disabled]=\"isLinkButtonDisabled\"\n      [hidden]=\"isButtonHidden('link')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'link']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'unlink-' + id\"\n      type=\"button\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('unlink')\"\n      title=\"Unlink\"\n      [disabled]=\"htmlMode || !linkSelected\"\n      [hidden]=\"isButtonHidden('unlink')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'unlink']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <input style=\"display: none\" accept=\"image/*\" type=\"file\" (change)=\"onFileChanged($event)\" #fileInput />\n    <button\n      [id]=\"'insertImage-' + id\"\n      type=\"button\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"fileInput.click()\"\n      title=\"Insert Image\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('insertImage')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'image']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <ng-container *ngIf=\"customButtons\">\n      <button\n        *ngFor=\"let button of customButtons\"\n        [id]=\"button.customButtonId + '-' + id\"\n        type=\"button\"\n        [class]=\"toolbarBtnClass\"\n        (click)=\"button.onClick()\"\n        [disabled]=\"htmlMode\"\n        tabindex=\"-1\"\n      >\n        <fa-icon [icon]=\"button.faIcon\" [fixedWidth]=\"true\"></fa-icon>\n      </button>\n    </ng-container>\n    <button\n      [id]=\"'insertVideo-' + id\"\n      type=\"button\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"insertVideo()\"\n      title=\"Insert Video\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('insertVideo')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'video']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n    <button\n      [id]=\"'insertHorizontalRule-' + id\"\n      type=\"button\"\n      title=\"Horizontal Line\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('insertHorizontalRule')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('insertHorizontalRule')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'minus']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n  </div>\n  <div class=\"btn-group m-1\">\n    <button\n      [id]=\"'clearFormatting-' + id\"\n      type=\"button\"\n      title=\"Clear Formatting\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('removeFormat')\"\n      [disabled]=\"htmlMode\"\n      [hidden]=\"isButtonHidden('removeFormat')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'remove-format']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n  </div>\n  <div class=\"btn-group m-1\">\n    <button\n      [id]=\"'toggleEditorMode-' + id\"\n      type=\"button\"\n      title=\"HTML Code\"\n      [class]=\"toolbarBtnClass\"\n      (click)=\"triggerCommand('toggleEditorMode')\"\n      [hidden]=\"isButtonHidden('toggleEditorMode')\"\n      tabindex=\"-1\"\n    >\n      <fa-icon [icon]=\"['fas', 'code']\" [fixedWidth]=\"true\"></fa-icon>\n    </button>\n  </div>\n</div>\n" }]
        }], ctorParameters: function () {
        return [{ type: i0.Renderer2 }, { type: AngularEditorService }, { type: undefined, decorators: [{
                        type: Inject,
                        args: [DOCUMENT]
                    }] }, { type: i0.ElementRef }];
    }, propDecorators: { id: [{
                type: Input
            }], uploadUrl: [{
                type: Input
            }], showToolbar: [{
                type: Input
            }], fonts: [{
                type: Input
            }], toolbarBgClass: [{
                type: Input
            }], toolbarBtnClass: [{
                type: Input
            }], customButtons: [{
                type: Input
            }], customClasses: [{
                type: Input
            }], defaultFontName: [{
                type: Input
            }], defaultFontSize: [{
                type: Input
            }], hiddenButtons: [{
                type: Input
            }], execute: [{
                type: Output
            }], myInputFile: [{
                type: ViewChild,
                args: ['fileInput', { static: true }]
            }] } });

class AngularEditorComponent {
    constructor(r, editorService, doc, sanitizer, cdRef, defaultTabIndex, autoFocus, elementRef, ngZone) {
        this.r = r;
        this.editorService = editorService;
        this.doc = doc;
        this.sanitizer = sanitizer;
        this.cdRef = cdRef;
        this.autoFocus = autoFocus;
        this.elementRef = elementRef;
        this.ngZone = ngZone;
        this.modeVisual = true;
        this.showPlaceholder = false;
        this.disabled = false;
        this.focused = false;
        this.touched = false;
        this.changed = false;
        this.floating = false;
        this.id = '';
        this.config = angularEditorConfig;
        this.placeholder = '';
        this._bodyContainer = null;
        this.viewMode = new EventEmitter();
        /** emits `blur` event when focused out from the textarea */
        // tslint:disable-next-line:no-output-native no-output-rename
        this.blurEvent = new EventEmitter();
        /** emits `focus` event when focused in to the textarea */
        // tslint:disable-next-line:no-output-rename no-output-native
        this.focusEvent = new EventEmitter();
        this.tabindex = -1;
        const parsedTabIndex = Number(defaultTabIndex);
        this.tabIndex = parsedTabIndex || parsedTabIndex === 0 ? parsedTabIndex : null;
    }
    onFocus() {
        this.focus();
    }
    ngOnInit() {
        this.config.toolbarPosition = this.config.toolbarPosition ? this.config.toolbarPosition : angularEditorConfig.toolbarPosition;
        this.floating = this.config.toolbarPosition === 'floating';
        if (this.floating) {
            this.zoneSubscription = this.ngZone.onStable.subscribe(() => {
                this.positionToolbar();
            });
        }
    }
    ngAfterViewInit() {
        this.resetContainer();
        if (isDefined(this.autoFocus)) {
            this.focus();
        }
    }
    /**
     * Executed command from editor header buttons
     * @param command string from triggerCommand
     */
    executeCommand(command) {
        this.focus();
        switch (command) {
            case '': // noop
                return;
            case 'contentChange':
                this.onContentChange(this.textArea.nativeElement);
                break;
            case 'toggleEditorMode':
                this.toggleEditorMode(this.modeVisual);
                break;
            case 'clear':
                this.editorService.removeSelectedElements(this.getCustomTags());
                this.onContentChange(this.textArea.nativeElement);
                break;
            case 'default':
                this.editorService.removeSelectedElements('h1,h2,h3,h4,h5,h6,p,pre');
                this.onContentChange(this.textArea.nativeElement);
                break;
            default:
                this.editorService.executeCommand(command);
                break;
        }
        this.exec();
    }
    /**
     * focus event
     */
    onTextAreaFocus(event) {
        if (this.focused) {
            event.stopPropagation();
            return;
        }
        this.applyContainer(this.container);
        this.focused = true;
        this.focusEvent.emit(event);
        if (!this.touched || !this.changed) {
            this.editorService.executeInNextQueueIteration(() => {
                this.configure();
                this.touched = true;
            });
        }
    }
    /**
     * @description fires when cursor leaves textarea
     */
    onTextAreaMouseOut(event) {
        this.editorService.saveSelection();
    }
    /**
     * blur event
     */
    onTextAreaBlur(event) {
        /**
         * save selection if focussed out
         */
        this.editorService.executeInNextQueueIteration(this.editorService.saveSelection);
        if (typeof this.onTouched === 'function') {
            this.onTouched();
        }
        if (event.relatedTarget !== null) {
            const parent = event.relatedTarget.parentElement;
            if (!parent.classList.contains('angular-editor-toolbar-set') && !parent.classList.contains('ae-picker')) {
                this.blurEvent.emit(event);
                this.resetContainer();
                this.focused = false;
            }
        }
    }
    /**
     *  focus the text area when the editor is focused
     */
    focus() {
        if (this.modeVisual) {
            this.textArea.nativeElement.focus();
        }
        else {
            const sourceText = this.doc.getElementById('sourceText' + this.id);
            sourceText.focus();
            this.applyContainer(this.container);
            this.focused = true;
        }
    }
    /**
     * Executed from the contenteditable section while the input property changes
     * @param element html element from contenteditable
     */
    onContentChange(element) {
        let html = '';
        if (this.modeVisual) {
            html = element.innerHTML;
        }
        else {
            html = element.innerText;
        }
        if (!html || html === '<br>') {
            html = '';
        }
        if (typeof this.onChange === 'function') {
            this.onChange(this.config.sanitize || this.config.sanitize === undefined ? this.sanitizer.sanitize(SecurityContext.HTML, html) : html);
            if (!html !== this.showPlaceholder) {
                this.togglePlaceholder(this.showPlaceholder);
            }
        }
        this.changed = true;
    }
    /**
     * Set the function to be called
     * when the control receives a change event.
     *
     * @param fn a function
     */
    registerOnChange(fn) {
        this.onChange = (e) => (e === '<br>' ? fn('') : fn(e));
    }
    /**
     * Set the function to be called
     * when the control receives a touch event.
     *
     * @param fn a function
     */
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    /**
     * Write a new value to the element.
     *
     * @param value value to be executed when there is a change in contenteditable
     */
    writeValue(value) {
        if ((!value || value === '<br>' || value === '') !== this.showPlaceholder) {
            this.togglePlaceholder(this.showPlaceholder);
        }
        if (value === undefined || value === '' || value === '<br>') {
            value = null;
        }
        this.refreshView(value);
    }
    /**
     * refresh view/HTML of the editor
     *
     * @param value html string from the editor
     */
    refreshView(value) {
        const normalizedValue = value === null ? '' : value;
        this.r.setProperty(this.textArea.nativeElement, 'innerHTML', normalizedValue);
        return;
    }
    /**
     * toggles placeholder based on input string
     *
     * @param value A HTML string from the editor
     */
    togglePlaceholder(value) {
        if (!value) {
            this.r.addClass(this.editorWrapper.nativeElement, 'show-placeholder');
            this.showPlaceholder = true;
        }
        else {
            this.r.removeClass(this.editorWrapper.nativeElement, 'show-placeholder');
            this.showPlaceholder = false;
        }
    }
    /**
     * Implements disabled state for this element
     *
     * @param isDisabled Disabled flag
     */
    setDisabledState(isDisabled) {
        const div = this.textArea.nativeElement;
        const action = isDisabled ? 'addClass' : 'removeClass';
        this.r[action](div, 'disabled');
        this.disabled = isDisabled;
    }
    /**
     * toggles editor mode based on bToSource bool
     *
     * @param bToSource A boolean value from the editor
     */
    toggleEditorMode(bToSource) {
        let oContent;
        const editableElement = this.textArea.nativeElement;
        if (bToSource) {
            oContent = this.r.createText(editableElement.innerHTML);
            this.r.setProperty(editableElement, 'innerHTML', '');
            this.r.setProperty(editableElement, 'contentEditable', false);
            const oPre = this.r.createElement('pre');
            this.r.setStyle(oPre, 'margin', '0');
            this.r.setStyle(oPre, 'outline', 'none');
            const oCode = this.r.createElement('code');
            this.r.setProperty(oCode, 'id', 'sourceText' + this.id);
            this.r.setStyle(oCode, 'display', 'block');
            this.r.setStyle(oCode, 'white-space', 'pre-wrap');
            this.r.setStyle(oCode, 'word-break', 'keep-all');
            this.r.setStyle(oCode, 'outline', 'none');
            this.r.setStyle(oCode, 'margin', '0');
            this.r.setStyle(oCode, 'background-color', '#fff5b9');
            this.r.setProperty(oCode, 'contentEditable', true);
            this.r.appendChild(oCode, oContent);
            this.focusInstance = this.r.listen(oCode, 'focus', (event) => this.onTextAreaFocus(event));
            this.blurInstance = this.r.listen(oCode, 'blur', (event) => this.onTextAreaBlur(event));
            this.r.appendChild(oPre, oCode);
            this.r.appendChild(editableElement, oPre);
            // ToDo move to service
            this.doc.execCommand('defaultParagraphSeparator', false, 'div');
            this.modeVisual = false;
            this.viewMode.emit(false);
            oCode.focus();
        }
        else {
            if (this.doc.querySelectorAll) {
                this.r.setProperty(editableElement, 'innerHTML', editableElement.innerText);
            }
            else {
                oContent = this.doc.createRange();
                oContent.selectNodeContents(editableElement.firstChild);
                this.r.setProperty(editableElement, 'innerHTML', oContent.toString());
            }
            this.r.setProperty(editableElement, 'contentEditable', true);
            this.modeVisual = true;
            this.viewMode.emit(true);
            this.onContentChange(editableElement);
            editableElement.focus();
        }
        this.editorToolbar.setEditorMode(!this.modeVisual);
    }
    /**
     * toggles editor buttons when cursor moved or positioning
     *
     * Send a node array from the contentEditable of the editor
     */
    exec() {
        this.editorToolbar.triggerButtons();
        let userSelection;
        if (this.doc.getSelection) {
            userSelection = this.doc.getSelection();
            this.editorService.executeInNextQueueIteration(this.editorService.saveSelection);
        }
        let a = userSelection.focusNode;
        const els = [];
        while (a && a !== this.textArea.nativeElement) {
            els.unshift(a);
            a = a.parentNode;
        }
        this.editorToolbar.triggerBlocks(els);
    }
    configure() {
        this.editorService.uploadUrl = this.config.uploadUrl;
        this.editorService.uploadWithCredentials = this.config.uploadWithCredentials;
        if (this.config.defaultParagraphSeparator) {
            this.editorService.setDefaultParagraphSeparator(this.config.defaultParagraphSeparator);
        }
        if (this.config.defaultFontName) {
            this.editorService.setFontName(this.config.defaultFontName);
        }
        if (this.config.defaultFontSize) {
            this.editorService.setFontSize(this.config.defaultFontSize);
        }
    }
    getFonts() {
        const fonts = this.config.fonts ? this.config.fonts : angularEditorConfig.fonts;
        return fonts.map((x) => {
            return { label: x.name, value: x.name };
        });
    }
    getCustomTags() {
        const tags = ['span'];
        this.config.customClasses.forEach((x) => {
            if (x.tag !== undefined) {
                if (!tags.includes(x.tag)) {
                    tags.push(x.tag);
                }
            }
        });
        return tags.join(',');
    }
    ngOnDestroy() {
        var _a;
        if (this.blurInstance) {
            this.blurInstance();
        }
        if (this.focusInstance) {
            this.focusInstance();
        }
        this.resetContainer();
        (_a = this.zoneSubscription) === null || _a === void 0 ? void 0 : _a.unsubscribe();
    }
    filterStyles(html) {
        html = html.replace('position: fixed;', '');
        return html;
    }
    positionToolbar() {
        const menu = this.editorToolbar;
        if (this.focused && menu) {
            positionElements(this.angularEditor.nativeElement, this._bodyContainer || this.editorToolbar.nativeElement, ['top'], this.container === 'body');
        }
    }
    resetContainer() {
        const renderer = this.r;
        if (this.editorToolbar) {
            const editorElement = this.angularEditor.nativeElement;
            const toolbarMenuElement = this.editorToolbar.nativeElement;
            if (this.config.toolbarPosition === 'top') {
                renderer.insertBefore(editorElement, toolbarMenuElement, this.editorWrapper.nativeElement);
            }
            else {
                renderer.appendChild(editorElement, toolbarMenuElement);
            }
            renderer.removeStyle(toolbarMenuElement, 'position');
            renderer.removeStyle(toolbarMenuElement, 'transform');
        }
        if (this._bodyContainer) {
            renderer.removeChild(this.doc.body, this._bodyContainer);
            this._bodyContainer = null;
        }
    }
    applyContainer(container = null) {
        if (!this.floating) {
            return;
        }
        this.resetContainer();
        if (container === 'body') {
            const renderer = this.r;
            const toolbarMenuElement = this.editorToolbar.nativeElement;
            const bodyContainer = (this._bodyContainer = this._bodyContainer || renderer.createElement('div'));
            // Override some styles to have the positioning working
            renderer.setStyle(bodyContainer, 'position', 'absolute');
            renderer.setStyle(toolbarMenuElement, 'position', 'static');
            renderer.setStyle(bodyContainer, 'z-index', '1050');
            renderer.appendChild(bodyContainer, toolbarMenuElement);
            renderer.appendChild(this.doc.body, bodyContainer);
        }
    }
}
AngularEditorComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.0", ngImport: i0, type: AngularEditorComponent, deps: [{ token: i0.Renderer2 }, { token: AngularEditorService }, { token: DOCUMENT }, { token: i2.NgDompurifySanitizer }, { token: i0.ChangeDetectorRef }, { token: 'tabindex', attribute: true }, { token: 'autofocus', attribute: true }, { token: i0.ElementRef }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
AngularEditorComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.0", type: AngularEditorComponent, selector: "angular-editor", inputs: { id: "id", config: "config", placeholder: "placeholder", tabIndex: "tabIndex", container: "container" }, outputs: { html: "html", viewMode: "viewMode", blurEvent: "blur", focusEvent: "focus" }, host: { listeners: { "focus": "onFocus()" }, properties: { "attr.tabindex": "this.tabindex" } }, providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => AngularEditorComponent),
            multi: true,
        },
    ], viewQueries: [{ propertyName: "angularEditor", first: true, predicate: ["angularEditor"], descendants: true, static: true }, { propertyName: "textArea", first: true, predicate: ["editor"], descendants: true, static: true }, { propertyName: "editorWrapper", first: true, predicate: ["editorWrapper"], descendants: true, static: true }, { propertyName: "editorToolbar", first: true, predicate: ["editorToolbar"], descendants: true }], ngImport: i0, template: "<div class=\"angular-editor\" #angularEditor [style.width]=\"config.width\" [style.minWidth]=\"config.minWidth\" (blur)=\"onTextAreaBlur($event)\">\n  <angular-editor-toolbar\n    #editorToolbar\n    [id]=\"id\"\n    [uploadUrl]=\"config.uploadUrl\"\n    [showToolbar]=\"config.showToolbar !== undefined ? config.showToolbar : true\"\n    [fonts]=\"getFonts()\"\n    [customClasses]=\"config.customClasses\"\n    [customButtons]=\"config.customButtons\"\n    [defaultFontName]=\"config.defaultFontName\"\n    [defaultFontSize]=\"config.defaultFontSize\"\n    [hiddenButtons]=\"config.toolbarHiddenButtons\"\n    [toolbarBgClass]=\"config.toolbarBgClass\"\n    [toolbarBtnClass]=\"config.toolbarBtnClass\"\n    (execute)=\"executeCommand($event)\"\n    [class.d-none]=\"floating && !focused\"\n  ></angular-editor-toolbar>\n  <div class=\"angular-editor-wrapper\" #editorWrapper>\n    <div\n      #editor\n      class=\"angular-editor-textarea\"\n      [attr.contenteditable]=\"config.editable\"\n      [attr.tabindex]=\"disabled ? -1 : tabIndex\"\n      [attr.translate]=\"config.translate\"\n      [attr.spellcheck]=\"config.spellcheck\"\n      [style.height]=\"config.height\"\n      [style.minHeight]=\"config.minHeight\"\n      [style.maxHeight]=\"config.maxHeight\"\n      [style.outline]=\"config.outline === false ? 'none' : undefined\"\n      (input)=\"onContentChange($event.target)\"\n      (focus)=\"onTextAreaFocus($event)\"\n      (click)=\"exec()\"\n      (keyup)=\"exec()\"\n      (mouseout)=\"onTextAreaMouseOut($event)\"\n    ></div>\n    <span class=\"angular-editor-placeholder\">{{ placeholder || config['placeholder'] }}</span>\n  </div>\n</div>\n", components: [{ type: AngularEditorToolbarComponent, selector: "angular-editor-toolbar", inputs: ["id", "uploadUrl", "showToolbar", "fonts", "toolbarBgClass", "toolbarBtnClass", "customButtons", "customClasses", "defaultFontName", "defaultFontSize", "hiddenButtons"], outputs: ["execute"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.0", ngImport: i0, type: AngularEditorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'angular-editor', providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => AngularEditorComponent),
                            multi: true,
                        },
                    ], template: "<div class=\"angular-editor\" #angularEditor [style.width]=\"config.width\" [style.minWidth]=\"config.minWidth\" (blur)=\"onTextAreaBlur($event)\">\n  <angular-editor-toolbar\n    #editorToolbar\n    [id]=\"id\"\n    [uploadUrl]=\"config.uploadUrl\"\n    [showToolbar]=\"config.showToolbar !== undefined ? config.showToolbar : true\"\n    [fonts]=\"getFonts()\"\n    [customClasses]=\"config.customClasses\"\n    [customButtons]=\"config.customButtons\"\n    [defaultFontName]=\"config.defaultFontName\"\n    [defaultFontSize]=\"config.defaultFontSize\"\n    [hiddenButtons]=\"config.toolbarHiddenButtons\"\n    [toolbarBgClass]=\"config.toolbarBgClass\"\n    [toolbarBtnClass]=\"config.toolbarBtnClass\"\n    (execute)=\"executeCommand($event)\"\n    [class.d-none]=\"floating && !focused\"\n  ></angular-editor-toolbar>\n  <div class=\"angular-editor-wrapper\" #editorWrapper>\n    <div\n      #editor\n      class=\"angular-editor-textarea\"\n      [attr.contenteditable]=\"config.editable\"\n      [attr.tabindex]=\"disabled ? -1 : tabIndex\"\n      [attr.translate]=\"config.translate\"\n      [attr.spellcheck]=\"config.spellcheck\"\n      [style.height]=\"config.height\"\n      [style.minHeight]=\"config.minHeight\"\n      [style.maxHeight]=\"config.maxHeight\"\n      [style.outline]=\"config.outline === false ? 'none' : undefined\"\n      (input)=\"onContentChange($event.target)\"\n      (focus)=\"onTextAreaFocus($event)\"\n      (click)=\"exec()\"\n      (keyup)=\"exec()\"\n      (mouseout)=\"onTextAreaMouseOut($event)\"\n    ></div>\n    <span class=\"angular-editor-placeholder\">{{ placeholder || config['placeholder'] }}</span>\n  </div>\n</div>\n" }]
        }], ctorParameters: function () {
        return [{ type: i0.Renderer2 }, { type: AngularEditorService }, { type: undefined, decorators: [{
                        type: Inject,
                        args: [DOCUMENT]
                    }] }, { type: i2.NgDompurifySanitizer }, { type: i0.ChangeDetectorRef }, { type: undefined, decorators: [{
                        type: Attribute,
                        args: ['tabindex']
                    }] }, { type: undefined, decorators: [{
                        type: Attribute,
                        args: ['autofocus']
                    }] }, { type: i0.ElementRef }, { type: i0.NgZone }];
    }, propDecorators: { id: [{
                type: Input
            }], config: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], tabIndex: [{
                type: Input
            }], container: [{
                type: Input
            }], html: [{
                type: Output
            }], angularEditor: [{
                type: ViewChild,
                args: ['angularEditor', { static: true }]
            }], textArea: [{
                type: ViewChild,
                args: ['editor', { static: true }]
            }], editorWrapper: [{
                type: ViewChild,
                args: ['editorWrapper', { static: true }]
            }], editorToolbar: [{
                type: ViewChild,
                args: ['editorToolbar']
            }], viewMode: [{
                type: Output
            }], blurEvent: [{
                type: Output,
                args: ['blur']
            }], focusEvent: [{
                type: Output,
                args: ['focus']
            }], tabindex: [{
                type: HostBinding,
                args: ['attr.tabindex']
            }], onFocus: [{
                type: HostListener,
                args: ['focus']
            }] } });

class AngularEditorModule {
    constructor(library) {
        library.addIcons(faItalic, faBold, faSuperscript, faSubscript, faUnderline, faUndo, faAlignRight, faAlignCenter, faAlignLeft, faAlignJustify, faRedo, faStrikethrough, faIndent, faOutdent, faListUl, faListOl, faFont, faLink, faUnlink, faImage, faVideo, faMinus, faRemoveFormat, faCode, faHighlighter);
    }
}
AngularEditorModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.0", ngImport: i0, type: AngularEditorModule, deps: [{ token: i1$2.FaIconLibrary }], target: i0.ɵɵFactoryTarget.NgModule });
AngularEditorModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.0", ngImport: i0, type: AngularEditorModule, declarations: [AngularEditorComponent, AngularEditorToolbarComponent, AeSelectComponent], imports: [CommonModule, FormsModule, ReactiveFormsModule, FontAwesomeModule, NgbDropdownModule, ColorPickerModule], exports: [AngularEditorComponent, AngularEditorToolbarComponent] });
AngularEditorModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.0", ngImport: i0, type: AngularEditorModule, imports: [[
            CommonModule, FormsModule, ReactiveFormsModule, FontAwesomeModule, NgbDropdownModule, ColorPickerModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.0", ngImport: i0, type: AngularEditorModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule, FormsModule, ReactiveFormsModule, FontAwesomeModule, NgbDropdownModule, ColorPickerModule
                    ],
                    declarations: [AngularEditorComponent, AngularEditorToolbarComponent, AeSelectComponent],
                    exports: [AngularEditorComponent, AngularEditorToolbarComponent]
                }]
        }], ctorParameters: function () { return [{ type: i1$2.FaIconLibrary }]; } });

/*
 * Public API Surface of angular-editor
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AngularEditorComponent, AngularEditorModule, AngularEditorService, AngularEditorToolbarComponent };
//# sourceMappingURL=geargroup-angular-editor.mjs.map
